# ServersApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**getServerStatus**](ServersApi.md#getServerStatus) | **GET** /account/{accountId}/server/{serverId} | 
[**getServers**](ServersApi.md#getServers) | **GET** /account/{accountId}/servers | 
[**serverEmptyAllEmailQueues**](ServersApi.md#serverEmptyAllEmailQueues) | **DELETE** /account/{accountId}/server/{serverId}/sending_queues/all | 
[**serverEmptyEmailQueues**](ServersApi.md#serverEmptyEmailQueues) | **DELETE** /account/{accountId}/server/{serverId}/sending_queues | 
[**setServerSendngRate**](ServersApi.md#setServerSendngRate) | **POST** /account/{accountId}/server/{serverId}/sending_rate | 

<a name="getServerStatus"></a>
# **getServerStatus**
> InlineResponse20075 getServerStatus(accountId, serverId, cookie)



This report allows you to retrieve specific current status of a specific server. This request will actually directly interrogate the server for some of this information; in situations where the server is overloaded or down or very slow, *this API will fail.*  {{ACL: Account: Servers - Report}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.ServersApi;


ServersApi apiInstance = new ServersApi();
String accountId = "accountId_example"; // String | 
String serverId = "serverId_example"; // String | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse20075 result = apiInstance.getServerStatus(accountId, serverId, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ServersApi#getServerStatus");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **serverId** | **String**| Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. |
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse20075**](InlineResponse20075.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getServers"></a>
# **getServers**
> InlineResponse20074 getServers(accountId, cookie)



This report allows you to retrieve general information about all of the dedicated servers associated with your account. {{ACL: Account: Servers - Report}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.ServersApi;


ServersApi apiInstance = new ServersApi();
String accountId = "accountId_example"; // String | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse20074 result = apiInstance.getServers(accountId, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ServersApi#getServers");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse20074**](InlineResponse20074.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="serverEmptyAllEmailQueues"></a>
# **serverEmptyAllEmailQueues**
> serverEmptyAllEmailQueues(accountId, serverId, cookie)



This command allows you to remove all email messages that are queued.  These are the mail_queue_trying and mail_queue_unprocessed messages returned by the server status call.  Messages that have not yet been processed will be deleted by this call. 

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.ServersApi;


ServersApi apiInstance = new ServersApi();
String accountId = "accountId_example"; // String | 
String serverId = "serverId_example"; // String | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
String cookie = null; // String (optional. can leave as null) | 
try {
    apiInstance.serverEmptyAllEmailQueues(accountId, serverId, cookie);
} catch (ApiException e) {
    System.err.println("Exception when calling ServersApi#serverEmptyAllEmailQueues");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **serverId** | **String**| Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. |
 **cookie** | **String**|  | [optional]

### Return type

null (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

<a name="serverEmptyEmailQueues"></a>
# **serverEmptyEmailQueues**
> serverEmptyEmailQueues(accountId, serverId, cookie)



This command allows you to remove all email messages that are queued and trying to be delivered to recipients.  These are the mail_queue_trying messages returned by the server status call.  Messages that have not yet been processed are not deleted. 

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.ServersApi;


ServersApi apiInstance = new ServersApi();
String accountId = "accountId_example"; // String | 
String serverId = "serverId_example"; // String | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
String cookie = null; // String (optional. can leave as null) | 
try {
    apiInstance.serverEmptyEmailQueues(accountId, serverId, cookie);
} catch (ApiException e) {
    System.err.println("Exception when calling ServersApi#serverEmptyEmailQueues");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **serverId** | **String**| Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. |
 **cookie** | **String**|  | [optional]

### Return type

null (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

<a name="setServerSendngRate"></a>
# **setServerSendngRate**
> setServerSendngRate(accountId, serverId, body, cookie)



This command allows you to update the email processing rate limits for this server.  These rate limits govern the rate at which messages are processed and delivered to the queues for delivery to recipients, for IP Warmup purposes.  These settings to not impact messages already processed trying to be delivered to recipients.

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.ServersApi;


ServersApi apiInstance = new ServersApi();
String accountId = "accountId_example"; // String | 
String serverId = "serverId_example"; // String | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
ServerIdSendingRateBody body = new ServerIdSendingRateBody(); // ServerIdSendingRateBody | 
String cookie = null; // String (optional. can leave as null) | 
try {
    apiInstance.setServerSendngRate(accountId, serverId, body, cookie);
} catch (ApiException e) {
    System.err.println("Exception when calling ServersApi#setServerSendngRate");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **serverId** | **String**| Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. |
 **body** | [**ServerIdSendingRateBody**](ServerIdSendingRateBody.md)|  | [optional]
 **cookie** | **String**|  | [optional]

### Return type

null (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined

